@@ -11,9 +11,10 @@ from subprocess import Popen, PIPE, STDOUT
 
 from celery import Celery
 
-from render import RENDER_DIR
+from render import RENDER_DIR, LOG_DIR
 import render.aws as aws
 from render.logger import configure_logger
+from render.util import user_data
 
 celery = Celery()
 celery.config_from_object('render.celeryconfig')
@@ -126,17 +127,11 @@ class Render:
         if not self.scene.localfile.is_file():
             raise Exception("Local file does not exists")
 
-        work_path = self.scene.workdir / 'workpath'
-        work_path.mkdir(exist_ok=True)
-        working_folder = self.scene.workdir / 'working_folder'
-        working_folder.mkdir(exist_ok=True)
         max_cmd = Path(os.environ['ADSK_3DSMAX_x64_2018']) / '3dsmaxcmd'
         process = Popen([
             str(max_cmd),
             "-continueOnError",
             "-batchRender",
-            f"-workPath:{str(work_path)}"
-            f"-workingFolder:{str(working_folder)}"
             f'-outputName:{str(self.scene.workdir / f"0.{extension}")}',
             str(self.scene.localfile)],
             stderr=STDOUT,
@@ -157,9 +152,6 @@ class Render:
 
 
 def record_time(f):
-    def format_date(value: datetime):
-        return value.strftime('%H:%M:%S %d-%m-%Y')
-
     def wrapper(*args, **kwargs):
         begin = datetime.now()
         logger.info(f"Rendering is started!")
@@ -177,7 +169,7 @@ def collect_logs(scene: Scene, client: aws.S3):
     logger.info("Collecting log files...")
     for file in itertools.chain(
             # additional logs could be appended here
-            glob.glob(str(Path(os.environ['LOG_DIR']) / '*.log')),
+            glob.glob(str(LOG_DIR / '*.log')),
             glob.glob(str(scene.workdir / '*.log')),
     ):
         logger.info(f"Found log {file}")
@@ -189,16 +181,15 @@ def collect_logs(scene: Scene, client: aws.S3):
 
 def run(scene_key):
     assert os.environ['ADSK_3DSMAX_x64_2018'], "ADSK_3DSMAX_x64_2018 must be defined"
-    assert os.environ['AWS_ACCESS_KEY_ID'], "AWS_ACCESS_KEY_ID must be defined"
-    assert os.environ['AWS_SECRET_ACCESS_KEY'], "AWS_SECRET_ACCESS_KEY must be defined"
-    assert os.environ['AWS_ENDPOINT'], "AWS_ENDPOINT must be defined"
-    assert os.environ['AWS_BUCKET'], "AWS_BUCKET must be defined"
-    assert os.environ['LOG_DIR'], "LOG_DIR must be defined"
+    assert user_data['AWS_ACCESS_KEY_ID'], "AWS_ACCESS_KEY_ID must be defined"
+    assert user_data['AWS_SECRET_ACCESS_KEY'], "AWS_SECRET_ACCESS_KEY must be defined"
+    assert user_data['AWS_ENDPOINT'], "AWS_ENDPOINT must be defined"
+    assert user_data['AWS_BUCKET'], "AWS_BUCKET must be defined"
     s3 = aws.S3(
-        os.environ['AWS_BUCKET'],
-        aws_access_key_id=os.environ['AWS_ACCESS_KEY_ID'],
-        aws_secret_access_key=os.environ['AWS_SECRET_ACCESS_KEY'],
-        endpoint_url=os.environ['AWS_ENDPOINT'],
+        user_data['AWS_BUCKET'],
+        aws_access_key_id=user_data['AWS_ACCESS_KEY_ID'],
+        aws_secret_access_key=user_data['AWS_SECRET_ACCESS_KEY'],
+        endpoint_url=user_data['AWS_ENDPOINT'],
     )
     scene = Scene(scene_key)
     # configure current logger for the specific scene
